@@ -176,7 +176,9 @@ class _CachedFunction(object):
 
     def _put(self, hash_code_args, args, result, origin):
         try:
-            origin_str = serialize_tuple(origin).replace("/", "%").replace("\\", "%")
+            origin_str = serialize_tuple(origin).replace("/", "%")\
+                                                .replace("\\", "%")\
+                                                .replace(":", "%")
         except Exception, e:
             raise Exception("can not pickle %r beause of: %s" % (result, e.message,))
 
